aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/gpu/GrResourceProvider.h
diff options
context:
space:
mode:
authorGravatar Brian Salomon <bsalomon@google.com>2016-12-16 18:59:19 -0500
committerGravatar Skia Commit-Bot <skia-commit-bot@chromium.org>2016-12-17 00:35:39 +0000
commit2ee084e73056b0ad76b721017f576168b7306da3 (patch)
treea07e78e5b454be986463704ab480dfa97750671b /src/gpu/GrResourceProvider.h
parent903da79a19c35723ff198d56923250d5f3fe0f15 (diff)
Rename GrBatchAtlas -> GrDrawOpAtlas.
Change-Id: I776f37e42dcab8b16535c48df9c405b1f211f6c9 Reviewed-on: https://skia-review.googlesource.com/6165 Commit-Queue: Brian Salomon <brian@thesalomons.net> Reviewed-by: Brian Osman <brianosman@google.com>
Diffstat (limited to 'src/gpu/GrResourceProvider.h')
-rw-r--r--src/gpu/GrResourceProvider.h42
1 files changed, 21 insertions, 21 deletions
diff --git a/src/gpu/GrResourceProvider.h b/src/gpu/GrResourceProvider.h
index 45aa3afbaf..58bd1f8c3c 100644
--- a/src/gpu/GrResourceProvider.h
+++ b/src/gpu/GrResourceProvider.h
@@ -8,13 +8,13 @@
#ifndef GrResourceProvider_DEFINED
#define GrResourceProvider_DEFINED
-#include "GrDrawOpAtlas.h"
#include "GrBuffer.h"
+#include "GrDrawOpAtlas.h"
#include "GrGpu.h"
-#include "GrTextureProvider.h"
#include "GrPathRange.h"
+#include "GrTextureProvider.h"
-class GrBatchAtlas;
+class GrDrawOpAtlas;
class GrPath;
class GrRenderTarget;
class GrSingleOwner;
@@ -129,25 +129,25 @@ public:
return this->internalCreateApproxTexture(desc, flags);
}
/** Returns a GrBatchAtlas. This function can be called anywhere, but the returned atlas should
* only be used inside of GrOp::generateGeometry
* @param GrPixelConfig The pixel config which this atlas will store
* @param width width in pixels of the atlas
* @param height height in pixels of the atlas
* @param numPlotsX The number of plots the atlas should be broken up into in the X
* direction
* @param numPlotsY The number of plots the atlas should be broken up into in the Y
* direction
* @param func An eviction function which will be called whenever the atlas has to
* evict data
* @param data User supplied data which will be passed into func whenver an
* eviction occurs
*
* @return An initialized GrBatchAtlas, or nullptr if creation fails
*/
- std::unique_ptr<GrBatchAtlas> makeAtlas(GrPixelConfig, int width, int height,
- int numPlotsX, int numPlotsY,
- GrBatchAtlas::EvictionFunc func, void* data);
+ std::unique_ptr<GrDrawOpAtlas> makeAtlas(GrPixelConfig, int width, int height, int numPlotsX,
+ int numPlotsY, GrDrawOpAtlas::EvictionFunc func,
+ void* data);
/**
* If passed in render target already has a stencil buffer, return it. Otherwise attempt to
@@ -129,25 +129,25 @@ public:
return this->internalCreateApproxTexture(desc, flags);
}
- /** Returns a GrBatchAtlas. This function can be called anywhere, but the returned atlas should
- * only be used inside of GrOp::generateGeometry
- * @param GrPixelConfig The pixel config which this atlas will store
- * @param width width in pixels of the atlas
- * @param height height in pixels of the atlas
- * @param numPlotsX The number of plots the atlas should be broken up into in the X
- * direction
- * @param numPlotsY The number of plots the atlas should be broken up into in the Y
- * direction
- * @param func An eviction function which will be called whenever the atlas has to
- * evict data
- * @param data User supplied data which will be passed into func whenver an
- * eviction occurs
- *
- * @return An initialized GrBatchAtlas, or nullptr if creation fails
+ /**
+ * Returns a GrDrawOpAtlas. This function can be called anywhere, but the returned atlas
+ * should only be used inside of GrMeshDrawOp::onPrepareDraws.
+ * @param GrPixelConfig The pixel config which this atlas will store
+ * @param width width in pixels of the atlas
+ * @param height height in pixels of the atlas
+ * @param numPlotsX The number of plots the atlas should be broken up into in the X
+ * direction
+ * @param numPlotsY The number of plots the atlas should be broken up into in the Y
+ * direction
+ * @param func An eviction function which will be called whenever the atlas has to
+ * evict data
+ * @param data User supplied data which will be passed into func whenver an
+ * eviction occurs
+ * @return An initialized GrDrawOpAtlas, or nullptr if creation fails
*/